@@ -1,3 +1,5 @@
+from typing import Any
+
 import serial
 import socket
 
@@ -49,7 +51,7 @@ class Connect:
 
     def init(self):
         """
-        Sets up the Connect class. A required step before running any functions.
+        Sets up the Connect class and returns the class. A required step before running any functions.
         """
 
         if self.data_method == 'com':
@@ -62,7 +64,9 @@ class Connect:
         elif self.data_method == 'exe':
             return Exception("The data_method exe has not been implemented yet")
 
-    def read_line(self, do_check=True):
+        return self
+
+    def read_line(self, do_check=True) -> str | Exception | None:
         """
         Returns string of the latest data from the CTS. Returns None if no data is there.
 
@@ -81,7 +85,7 @@ class Connect:
         elif self.data_method == 'exe':
             return Exception("The data_method exe has not been implemented yet")
 
-    def get_cords(self, do_check=True):
+    def get_cords(self, do_check=True) -> [float]:
         """
         Returns array of the latest data from the CTS. Returns empty array if no data is there.
 
